@@ -1,4 +1,4 @@
-# Copyright (c) 2019-2021, Jonas Eschle, Jim Pivarski, Eduardo Rodrigues, and Henry Schreiner.
+# Copyright (c) 2019-2024, Jonas Eschle, Jim Pivarski, Eduardo Rodrigues, and Henry Schreiner.
 #
 # Distributed under the 3-clause BSD license, see accompanying file LICENSE
 # or https://github.com/scikit-hep/vector for details.
@@ -7,6 +7,8 @@ from __future__ import annotations
 
 import typing
 
+import numpy
+
 
 def _recname(is_momentum: bool, dimension: int) -> str:
     name = "Momentum" if is_momentum else "Vector"
@@ -230,7 +232,7 @@ def _is_type_safe(array_type: typing.Any) -> bool:
     )
     for field_type in contents:
         if isinstance(field_type, awkward.types.OptionType):
-            field_type = (
+            field_type = (  # noqa: PLW2901
                 field_type.content
                 if hasattr(array_type, "content")
                 else field_type.type
@@ -311,33 +313,43 @@ def Array(*args: typing.Any, **kwargs: typing.Any) -> typing.Any:
     import vector
     import vector.backends.awkward
 
-    akarray = awkward.Array(*args, **kwargs)
+    # don't pass dask_awkward arrays in ak.Array
+    akarray = (
+        awkward.Array(*args, **kwargs)
+        if isinstance(args[0], (list, numpy.ndarray))
+        else args[0]
+    )
     array_type = akarray.type
 
     if not _is_type_safe(array_type):
         raise TypeError("a coordinate must be of the type int or float")
     fields = awkward.fields(akarray)
 
-    is_momentum, dimension, names, arrays = _check_names(akarray, fields)
+    is_momentum, dimension, names, arrays = _check_names(akarray, fields.copy())
 
-    needs_behavior = not vector._awkward_registered
-    for x in arrays:
-        if needs_behavior:
-            if x.behavior is None:
-                x.behavior = vector.backends.awkward.behavior
+    # don't execute for dask_awkward arrays
+    if isinstance(args[0], (awkward.Array, list, numpy.ndarray)):
+        needs_behavior = not vector._awkward_registered
+        for x in arrays:
+            if needs_behavior:
+                if x.behavior is None:
+                    x.behavior = vector.backends.awkward.behavior
+                else:
+                    x.behavior = dict(x.behavior)
+                    x.behavior.update(vector.backends.awkward.behavior)
             else:
-                x.behavior = dict(x.behavior)
-                x.behavior.update(vector.backends.awkward.behavior)
-        else:
-            x.behavior = None
-        needs_behavior = False
+                x.behavior = None
+            needs_behavior = False
 
     assert 2 <= dimension <= 4, f"Dimension must be between 2-4, not {dimension}"
 
-    return awkward.zip(
-        dict(__builtins__["zip"](names, arrays)),  # type: ignore[index]
-        depth_limit=akarray.layout.purelist_depth,
-        with_name=_recname(is_momentum, dimension),
+    return awkward.with_name(
+        awkward.zip(
+            dict(__builtins__["zip"](names, arrays)),  # type: ignore[index]
+            depth_limit=akarray.layout.purelist_depth,
+        ),
+        _recname(is_momentum, dimension),
+        behavior=vector.backends.awkward.behavior,
     )
 
 
